clear all
use HCUP_Data.dta

set more off

xtset st qt

local di_cov = "HN"

label var prescriptionlimit "Prescription Limit"
label var pdmp "PDMP"
label var physicianexam "Physician Exam"
label var trpf "Tamper Resistant PF"
label var requireid "Require ID"
label var pharmacistverification "Pharm. Verif."
label var doctorshopping "Doctor Shopping"
label var painclinic "Pain Clinic"
label var T_GS_HasLaw "Good Samaritan Law (GS)"

local i=0

local C1 ""
local C2 "i.qt"
local C3 "c.t##i.st"
local C5 "T_GS_HasLaw"
local C6 "pdmp doctorshopping painclinic"
local C7 "physicianexam pharmacistverification requireid"
local C8 "trpf"
local C9 ""

label var ED_Metro "All ED Metro"

gen dd0=0
replace dd0=1 if diff<-4 & mini<0
gen dd1=0
replace dd1=1 if diff>=-4 & diff<=-4  & mini<0
gen dd2=0
replace dd2=1 if diff>=-3 & diff<=-3 & mini<0
gen dd3=0
replace dd3=1 if diff>=-2 & diff<=-2 & mini<0

gen dd4=0
replace dd4=1 if mini>=0

gen dd5=0
replace dd5=1 if diff>=0 & diff<=0 & mini<0
gen dd6=0
replace dd6=1 if diff>=1 & diff<=1 & mini<0
gen dd7=0
replace dd7=1 if diff>=2 & diff<=2 & mini<0
gen dd8=0
replace dd8=1 if diff>=3 & mini<0

label var dd0 "-5"
label var dd1 "-4"
label var dd2 "-3"
label var dd3 "-2"
label var dd4 "-1"
label var dd5 "0"
label var dd6 "1"
label var dd7 "2"
label var dd8 "3"



foreach K in "`C1'" "`C2'" "`C3'" "`C4'" "`C5'" "`C6'" "`C7'" "`C8'" "`C9'" {
local covariates = "`K'" + " " + "`covariates'"
}

label var ED_Metro "Opioid-related ER visits"

foreach D of varlist ED_Metro {

local i=`i'+1

xtreg  `D' `covariates' dd* , fe cluster(st)
eststo s`i'
reg `D'
eststo a`i'

local vtext : variable label `D'

local ymin=-1000
local ymax=1000
local lymin=-1000
local lymax=1000
local step=500



coefplot (s`i', keep(dd0 dd1 dd2 dd3) lcolor(black) mcolor(black) offset(-0.01) )  ///
(s`i', keep(dd4) omitted lcolor(black) mcolor(black)) ///
 (s`i', keep(dd5 dd6 dd7 dd8) lcolor(black) mcolor(black) offset(-0.01) ) ///
   ,  vertical label  graphregion(fcolor(white))  recast(connected) lwidth(*2) ciopts(recast(rline) lpattern(dash) lcolor(black)) legend(off) xline(5.5, lpattern(dash)) ///
 ylabel(`lymin' (`step') `lymax')   yscale(r(`ymin' `ymax')) title("`vtext'") xtitle("Quarter Since Naloxone Law")
graph save plots/`D'_coef.gph, replace
graph export plots/`D'_coef.png, as(png)  replace width(4000)



}



