clear all
use Mort_Data.dta

set matsize 11000
set more off

local i=0
xtset CNT my
encode ST, g(st) 

sort st t
bys st: egen t13=sum(HN*(year==2013))
bys st: egen t14=sum(HN*(year==2014))
bys st: egen t15=sum(HN*(year==2015))
replace t13=1 if t13>0
replace t14=1 if t14>0
replace t15=1 if t15>0

gen g14=(t14==1)
gen g15=(t15==1 & t14==0)

gen treat=0
replace treat=1 if g14==1
replace treat=2 if g15==1


label var prescriptionlimit "Prescription Limit"
label var pdmp "PDMP"
label var physicianexam "Physician Exam"
label var trpf "Tamper Resistant PF"
label var requireid "Require ID"
label var pharmacistverification "Pharm. Verif."
label var doctorshopping "Doctor Shopping"
label var painclinic "Pain Clinic"
label var T_GS_HasLaw "Good Samaritan Law (GS)"

local i=0

local C1 ""
local C2 "i.t"
local C3 "c.t##i.st"
local C4 "LogPoliceRate"
local C5 "T_GS_HasLaw"
local C6 "pdmp doctorshopping painclinic"
local C7 "physicianexam pharmacistverification requireid"
local C8 "trpf"
local C9 ""

foreach K in "`C1'" "`C2'" "`C3'" "`C4'" "`C5'" "`C6'" "`C7'" "`C8'" "`C9'"  {
local covariates = "`K'" + " " + "`covariates'"
}

{
gen dd0=0
replace dd0=1 if diff<-12  & mini<0 & treat==1
gen dd1=0
replace dd1=1 if diff>=-12 & diff<=-10  & mini<0 & treat==1
gen dd2=0
replace dd2=1 if diff>=-9 & diff<=-7 & mini<0 & treat==1
gen dd3=0
replace dd3=1 if diff>=-6 & diff<=-4 & mini<0 & treat==1

gen dd4=0
replace dd4=1 if mini>=0 & treat==1

gen dd5=0
replace dd5=1 if diff>=0 & diff<=2 & mini<0 & treat==1
gen dd6=0
replace dd6=1 if diff>=3 & diff<=5 & mini<0 & treat==1
gen dd7=0
replace dd7=1 if diff>=6 & mini<0 & treat==1
}

{
gen yy0=0
replace yy0=1 if diff<-12  & mini<0 & treat==2
gen yy1=0
replace yy1=1 if diff>=-12 & diff<=-10  & mini<0 & treat==2
gen yy2=0
replace yy2=1 if diff>=-9 & diff<=-7 & mini<0 & treat==2
gen yy3=0
replace yy3=1 if diff>=-6 & diff<=-4 & mini<0 & treat==2

gen yy4=0
replace yy4=1 if mini>=0 & treat==2

gen yy5=0
replace yy5=1 if diff>=0 & diff<=2 & mini<0 & treat==2
gen yy6=0
replace yy6=1 if diff>=3 & diff<=5 & mini<0 & treat==2
gen yy7=0
replace yy7=1 if diff>=6 & mini<0 & treat==2
}

label var dd0 "-5"
label var dd1 "-4"
label var dd2 "-3"
label var dd3 "-2"
label var dd4 "-1"
label var dd5 "0"
label var dd6 "1"
label var dd7 "2"

label var yy0 "-5"
label var yy1 "-4"
label var yy2 "-3"
label var yy3 "-2"
label var yy4 "-1"
label var yy5 "0"
label var yy6 "1"
label var yy7 "2"

label var s_All_Rate  "Opioid-related deaths"
label var s_AllSynthetic_Rate  "Fentanyl-related deaths"
  
foreach D of varlist  s_All_Rate  s_AllSynthetic_Rate {

local i=`i'+1

xtreg  `D' `covariates' dd* yy* [aweight=pop_state_2010], fe cluster(st)
eststo s`i'

local vtext : variable label `D'

local offs=-8
local offs2=-7.8
coefplot (s`i', keep(dd0 dd1 dd2 dd3) lcolor(black) mcolor(black) offset(-0.01) )  ///
(s`i', keep(dd4) omitted lcolor(black) mcolor(black)) ///
 (s`i', keep(dd5 dd6 dd7) lcolor(black) mcolor(black) offset(-0.01) ) ///
  (s`i', keep(yy0 yy1 yy2 yy3) lcolor(blue) mcolor(blue) msymbol(S) msize(medsmall) offset(`offs2') )  ///
(s`i', keep(yy4) omitted lcolor(blue) mcolor(blue) msymbol(S) msize(medsmall) offset(`offs')) ///
 (s`i', keep(yy5 yy6 yy7) lcolor(blue) mcolor(blue) msymbol(S) msize(medsmall) offset(`offs2') ) ///
   ,  vertical label  graphregion(fcolor(white))  recast(connected) lwidth(*2) ciopts(recast(rcap) lpattern(dash) lcolor(gray)) legend(off) xline(5.5, lpattern(dash)) ///
 title("`vtext'                                                                                ") xtitle("Quarter Since Naloxone Law                                                                                                                ") xscale(r(0(1)10)) xsize(10)

graph save plots/`D'_coef.gph, replace
graph export plots/`D'_coef.png, as(png)  replace width(4000)

}

